.extended-autocomplete-select-multiply-container {
    box-sizing: border-box;
    display: inline-block;
    margin: 0;
    position: relative;
    vertical-align: middle;
}

.extended-autocomplete-select-multiply-container .extended-autocomplete-select-multiply-selection--single {
    box-sizing: border-box;
    cursor: pointer;
    display: block;
    height: 28px;
    user-select: none;
    -webkit-user-select: none;
}

.extended-autocomplete-select-multiply-container .extended-autocomplete-select-multiply-selection--single .extended-autocomplete-select-multiply-selection__rendered {
    display: block;
    padding-left: 8px;
    padding-right: 20px;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
}

.extended-autocomplete-select-multiply-container .extended-autocomplete-select-multiply-selection--single .extended-autocomplete-select-multiply-selection__clear {
    position: relative;
}

.extended-autocomplete-select-multiply-container[dir="rtl"] .extended-autocomplete-select-multiply-selection--single .extended-autocomplete-select-multiply-selection__rendered {
    padding-right: 8px;
    padding-left: 20px;
}

.extended-autocomplete-select-multiply-container .extended-autocomplete-select-multiply-selection--multiple {
    box-sizing: border-box;
    cursor: pointer;
    display: block;
    min-height: 32px;
    user-select: none;
    -webkit-user-select: none;
}

.extended-autocomplete-select-multiply-container .extended-autocomplete-select-multiply-selection--multiple .extended-autocomplete-select-multiply-selection__rendered {
    display: inline-block;
    overflow: hidden;
    padding-left: 8px;
    text-overflow: ellipsis;
    white-space: nowrap;
}

.extended-autocomplete-select-multiply-container .extended-autocomplete-select-multiply-search--inline {
    float: left;
}

.extended-autocomplete-select-multiply-container .extended-autocomplete-select-multiply-search--inline .extended-autocomplete-select-multiply-search__field {
    box-sizing: border-box;
    border: none;
    font-size: 100%;
    margin-top: 5px;
    padding: 0;
}

.extended-autocomplete-select-multiply-container .extended-autocomplete-select-multiply-search--inline .extended-autocomplete-select-multiply-search__field::-webkit-search-cancel-button {
    -webkit-appearance: none;
}

.extended-autocomplete-select-multiply-dropdown {
    background-color: white;
    border: 1px solid #aaa;
    border-radius: 0px;
    box-sizing: border-box;
    display: block;
    position: absolute;
    left: -100000px;
    width: 100%;
    z-index: 1051;
}

.extended-autocomplete-select-multiply-results {
    display: block;
}

.extended-autocomplete-select-multiply-results__options {
    list-style: none;
    margin: 0;
    padding: 0;
}

.extended-autocomplete-select-multiply-results__option {
    padding: 6px;
    user-select: none;
    -webkit-user-select: none;
}

.extended-autocomplete-select-multiply-results__option[aria-selected] {
    cursor: pointer;
}

.extended-autocomplete-select-multiply-container--open .extended-autocomplete-select-multiply-dropdown {
    left: 0;
}

.extended-autocomplete-select-multiply-container--open .extended-autocomplete-select-multiply-dropdown--above {
    border-bottom: none;
    border-bottom-left-radius: 0;
    border-bottom-right-radius: 0;
}

.extended-autocomplete-select-multiply-container--open .extended-autocomplete-select-multiply-dropdown--below {
    border-top: none;
    border-top-left-radius: 0;
    border-top-right-radius: 0;
}

.extended-autocomplete-select-multiply-search--dropdown {
    display: block;
    padding: 4px;
}

.extended-autocomplete-select-multiply-search--dropdown .extended-autocomplete-select-multiply-search__field {
    padding: 4px;
    width: 100%;
    box-sizing: border-box;
}

.extended-autocomplete-select-multiply-search--dropdown .extended-autocomplete-select-multiply-search__field::-webkit-search-cancel-button {
    -webkit-appearance: none;
}

.extended-autocomplete-select-multiply-search--dropdown.extended-autocomplete-select-multiply-search--hide {
    display: none;
}

.extended-autocomplete-select-multiply-close-mask {
    border: 0;
    margin: 0;
    padding: 0;
    display: block;
    position: fixed;
    left: 0;
    top: 0;
    min-height: 100%;
    min-width: 100%;
    height: auto;
    width: auto;
    opacity: 0;
    z-index: 99;
    background-color: #fff;
    filter: alpha(opacity=0);
}

.extended-autocomplete-select-multiply-hidden-accessible {
    border: 0 !important;
    clip: rect(0 0 0 0) !important;
    -webkit-clip-path: inset(50%) !important;
    clip-path: inset(50%) !important;
    height: 1px !important;
    overflow: hidden !important;
    padding: 0 !important;
    position: absolute !important;
    width: 1px !important;
    white-space: nowrap !important;
}

.extended-autocomplete-select-multiply-container--default .extended-autocomplete-select-multiply-selection--single {
    background-color: #fff;
    border: 1px solid #aaa;
    border-radius: 0px;
}

.extended-autocomplete-select-multiply-container--default .extended-autocomplete-select-multiply-selection--single .extended-autocomplete-select-multiply-selection__rendered {
    color: #444;
    line-height: 28px;
}

.extended-autocomplete-select-multiply-container--default .extended-autocomplete-select-multiply-selection--single .extended-autocomplete-select-multiply-selection__clear {
    cursor: pointer;
    float: right;
    font-weight: bold;
}

.extended-autocomplete-select-multiply-container--default .extended-autocomplete-select-multiply-selection--single .extended-autocomplete-select-multiply-selection__placeholder {
    color: #999;
}

.extended-autocomplete-select-multiply-container--default .extended-autocomplete-select-multiply-selection--single .extended-autocomplete-select-multiply-selection__arrow {
    height: 26px;
    position: absolute;
    top: 1px;
    right: 1px;
    width: 20px;
}

.extended-autocomplete-select-multiply-container--default .extended-autocomplete-select-multiply-selection--single .extended-autocomplete-select-multiply-selection__arrow b {
    border-color: #888 transparent transparent transparent;
    border-style: solid;
    border-width: 5px 4px 0 4px;
    height: 0;
    left: 50%;
    margin-left: -4px;
    margin-top: -2px;
    position: absolute;
    top: 50%;
    width: 0;
}

.extended-autocomplete-select-multiply-container--default[dir="rtl"] .extended-autocomplete-select-multiply-selection--single .extended-autocomplete-select-multiply-selection__clear {
    float: left;
}

.extended-autocomplete-select-multiply-container--default[dir="rtl"] .extended-autocomplete-select-multiply-selection--single .extended-autocomplete-select-multiply-selection__arrow {
    left: 1px;
    right: auto;
}

.extended-autocomplete-select-multiply-container--default.extended-autocomplete-select-multiply-container--disabled .extended-autocomplete-select-multiply-selection--single {
    background-color: #eee;
    cursor: default;
}

.extended-autocomplete-select-multiply-container--default.extended-autocomplete-select-multiply-container--disabled .extended-autocomplete-select-multiply-selection--single .extended-autocomplete-select-multiply-selection__clear {
    display: none;
}

.extended-autocomplete-select-multiply-container--default.extended-autocomplete-select-multiply-container--open .extended-autocomplete-select-multiply-selection--single .extended-autocomplete-select-multiply-selection__arrow b {
    border-color: transparent transparent #888 transparent;
    border-width: 0 4px 5px 4px;
}

.extended-autocomplete-select-multiply-container--default .extended-autocomplete-select-multiply-selection--multiple {
    background-color: white;
    border: 1px solid #aaa;
    border-radius: 0px;
    cursor: text;
}

.extended-autocomplete-select-multiply-container--default .extended-autocomplete-select-multiply-selection--multiple .extended-autocomplete-select-multiply-selection__rendered {
    box-sizing: border-box;
    list-style: none;
    margin: 0;
    padding: 0 5px;
    width: 100%;
}

.extended-autocomplete-select-multiply-container--default .extended-autocomplete-select-multiply-selection--multiple .extended-autocomplete-select-multiply-selection__rendered li {
    list-style: none;
}

.extended-autocomplete-select-multiply-container--default .extended-autocomplete-select-multiply-selection--multiple .extended-autocomplete-select-multiply-selection__clear {
    cursor: pointer;
    float: right;
    font-weight: bold;
    margin-top: 5px;
    margin-right: 10px;
    padding: 1px;
}

.extended-autocomplete-select-multiply-container--default .extended-autocomplete-select-multiply-selection--multiple .extended-autocomplete-select-multiply-selection__choice {
    background-color: #e4e4e4;
    border: 1px solid #aaa;
    border-radius: 0px;
    cursor: default;
    float: left;
    margin-right: 5px;
    margin-top: 5px;
    padding: 0 5px;
}

.extended-autocomplete-select-multiply-container--default .extended-autocomplete-select-multiply-selection--multiple .extended-autocomplete-select-multiply-selection__choice__remove {
    color: #999;
    cursor: pointer;
    display: inline-block;
    font-weight: bold;
    margin-right: 2px;
}

.extended-autocomplete-select-multiply-container--default .extended-autocomplete-select-multiply-selection--multiple .extended-autocomplete-select-multiply-selection__choice__remove:hover {
    color: #333;
}

.extended-autocomplete-select-multiply-container--default[dir="rtl"] .extended-autocomplete-select-multiply-selection--multiple .extended-autocomplete-select-multiply-selection__choice, .extended-autocomplete-select-multiply-container--default[dir="rtl"] .extended-autocomplete-select-multiply-selection--multiple .extended-autocomplete-select-multiply-search--inline {
    float: right;
}

.extended-autocomplete-select-multiply-container--default[dir="rtl"] .extended-autocomplete-select-multiply-selection--multiple .extended-autocomplete-select-multiply-selection__choice {
    margin-left: 5px;
    margin-right: auto;
}

.extended-autocomplete-select-multiply-container--default[dir="rtl"] .extended-autocomplete-select-multiply-selection--multiple .extended-autocomplete-select-multiply-selection__choice__remove {
    margin-left: 2px;
    margin-right: auto;
}

.extended-autocomplete-select-multiply-container--default.extended-autocomplete-select-multiply-container--focus .extended-autocomplete-select-multiply-selection--multiple {
    border: solid black 1px;
    outline: 0;
}

.extended-autocomplete-select-multiply-container--default.extended-autocomplete-select-multiply-container--disabled .extended-autocomplete-select-multiply-selection--multiple {
    background-color: #eee;
    cursor: default;
}

.extended-autocomplete-select-multiply-container--default.extended-autocomplete-select-multiply-container--disabled .extended-autocomplete-select-multiply-selection__choice__remove {
    display: none;
}

.extended-autocomplete-select-multiply-container--default.extended-autocomplete-select-multiply-container--open.extended-autocomplete-select-multiply-container--above .extended-autocomplete-select-multiply-selection--single, .extended-autocomplete-select-multiply-container--default.extended-autocomplete-select-multiply-container--open.extended-autocomplete-select-multiply-container--above .extended-autocomplete-select-multiply-selection--multiple {
    border-top-left-radius: 0;
    border-top-right-radius: 0;
}

.extended-autocomplete-select-multiply-container--default.extended-autocomplete-select-multiply-container--open.extended-autocomplete-select-multiply-container--below .extended-autocomplete-select-multiply-selection--single, .extended-autocomplete-select-multiply-container--default.extended-autocomplete-select-multiply-container--open.extended-autocomplete-select-multiply-container--below .extended-autocomplete-select-multiply-selection--multiple {
    border-bottom-left-radius: 0;
    border-bottom-right-radius: 0;
}

.extended-autocomplete-select-multiply-container--default .extended-autocomplete-select-multiply-search--dropdown .extended-autocomplete-select-multiply-search__field {
    border: 1px solid #aaa;
}

.extended-autocomplete-select-multiply-container--default .extended-autocomplete-select-multiply-search--inline .extended-autocomplete-select-multiply-search__field {
    background: transparent;
    border: none;
    outline: 0;
    box-shadow: none;
    -webkit-appearance: textfield;
}

.extended-autocomplete-select-multiply-container--default .extended-autocomplete-select-multiply-results>.extended-autocomplete-select-multiply-results__options {
    max-height: 200px;
    overflow-y: auto;
}

.extended-autocomplete-select-multiply-container--default .extended-autocomplete-select-multiply-results__option[role=group] {
    padding: 0;
}

.extended-autocomplete-select-multiply-container--default .extended-autocomplete-select-multiply-results__option[aria-disabled=true] {
    color: #999;
}

.extended-autocomplete-select-multiply-container--default .extended-autocomplete-select-multiply-results__option[aria-selected=true] {
    background-color: #ddd;
}

.extended-autocomplete-select-multiply-container--default .extended-autocomplete-select-multiply-results__option .extended-autocomplete-select-multiply-results__option {
    padding-left: 1em;
}

.extended-autocomplete-select-multiply-container--default .extended-autocomplete-select-multiply-results__option .extended-autocomplete-select-multiply-results__option .extended-autocomplete-select-multiply-results__group {
    padding-left: 0;
}

.extended-autocomplete-select-multiply-container--default .extended-autocomplete-select-multiply-results__option .extended-autocomplete-select-multiply-results__option .extended-autocomplete-select-multiply-results__option {
    margin-left: -1em;
    padding-left: 2em;
}

.extended-autocomplete-select-multiply-container--default .extended-autocomplete-select-multiply-results__option .extended-autocomplete-select-multiply-results__option .extended-autocomplete-select-multiply-results__option .extended-autocomplete-select-multiply-results__option {
    margin-left: -2em;
    padding-left: 3em;
}

.extended-autocomplete-select-multiply-container--default .extended-autocomplete-select-multiply-results__option .extended-autocomplete-select-multiply-results__option .extended-autocomplete-select-multiply-results__option .extended-autocomplete-select-multiply-results__option .extended-autocomplete-select-multiply-results__option {
    margin-left: -3em;
    padding-left: 4em;
}

.extended-autocomplete-select-multiply-container--default .extended-autocomplete-select-multiply-results__option .extended-autocomplete-select-multiply-results__option .extended-autocomplete-select-multiply-results__option .extended-autocomplete-select-multiply-results__option .extended-autocomplete-select-multiply-results__option .extended-autocomplete-select-multiply-results__option {
    margin-left: -4em;
    padding-left: 5em;
}

.extended-autocomplete-select-multiply-container--default .extended-autocomplete-select-multiply-results__option .extended-autocomplete-select-multiply-results__option .extended-autocomplete-select-multiply-results__option .extended-autocomplete-select-multiply-results__option .extended-autocomplete-select-multiply-results__option .extended-autocomplete-select-multiply-results__option .extended-autocomplete-select-multiply-results__option {
    margin-left: -5em;
    padding-left: 6em;
}

.extended-autocomplete-select-multiply-container--default .extended-autocomplete-select-multiply-results__option--highlighted[aria-selected] {
    background-color: #5897fb;
    color: white;
}

.extended-autocomplete-select-multiply-container--default .extended-autocomplete-select-multiply-results__group {
    cursor: default;
    display: block;
    padding: 6px;
}

.extended-autocomplete-select-multiply-container--classic .extended-autocomplete-select-multiply-selection--single {
    background-color: #f7f7f7;
    border: 1px solid #aaa;
    border-radius: 0px;
    outline: 0;
    background-image: -webkit-linear-gradient(top, white 50%, #eeeeee 100%);
    background-image: -o-linear-gradient(top, white 50%, #eeeeee 100%);
    background-image: linear-gradient(to bottom, white 50%, #eeeeee 100%);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#FFFFFFFF', endColorstr='#FFEEEEEE', GradientType=0);
}

.extended-autocomplete-select-multiply-container--classic .extended-autocomplete-select-multiply-selection--single:focus {
    border: 1px solid #5897fb;
}

.extended-autocomplete-select-multiply-container--classic .extended-autocomplete-select-multiply-selection--single .extended-autocomplete-select-multiply-selection__rendered {
    color: #444;
    line-height: 28px;
}

.extended-autocomplete-select-multiply-container--classic .extended-autocomplete-select-multiply-selection--single .extended-autocomplete-select-multiply-selection__clear {
    cursor: pointer;
    float: right;
    font-weight: bold;
    margin-right: 10px;
}

.extended-autocomplete-select-multiply-container--classic .extended-autocomplete-select-multiply-selection--single .extended-autocomplete-select-multiply-selection__placeholder {
    color: #999;
}

.extended-autocomplete-select-multiply-container--classic .extended-autocomplete-select-multiply-selection--single .extended-autocomplete-select-multiply-selection__arrow {
    background-color: #ddd;
    border: none;
    border-left: 1px solid #aaa;
    border-top-right-radius: 0px;
    border-bottom-right-radius: 0px;
    height: 26px;
    position: absolute;
    top: 1px;
    right: 1px;
    width: 20px;
    background-image: -webkit-linear-gradient(top, #eeeeee 50%, #cccccc 100%);
    background-image: -o-linear-gradient(top, #eeeeee 50%, #cccccc 100%);
    background-image: linear-gradient(to bottom, #eeeeee 50%, #cccccc 100%);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#FFEEEEEE', endColorstr='#FFCCCCCC', GradientType=0);
}

.extended-autocomplete-select-multiply-container--classic .extended-autocomplete-select-multiply-selection--single .extended-autocomplete-select-multiply-selection__arrow b {
    border-color: #888 transparent transparent transparent;
    border-style: solid;
    border-width: 5px 4px 0 4px;
    height: 0;
    left: 50%;
    margin-left: -4px;
    margin-top: -2px;
    position: absolute;
    top: 50%;
    width: 0;
}

.extended-autocomplete-select-multiply-container--classic[dir="rtl"] .extended-autocomplete-select-multiply-selection--single .extended-autocomplete-select-multiply-selection__clear {
    float: left;
}

.extended-autocomplete-select-multiply-container--classic[dir="rtl"] .extended-autocomplete-select-multiply-selection--single .extended-autocomplete-select-multiply-selection__arrow {
    border: none;
    border-right: 1px solid #aaa;
    border-radius: 0;
    border-top-left-radius: 0px;
    border-bottom-left-radius: 0px;
    left: 1px;
    right: auto;
}

.extended-autocomplete-select-multiply-container--classic.extended-autocomplete-select-multiply-container--open .extended-autocomplete-select-multiply-selection--single {
    border: 1px solid #5897fb;
}

.extended-autocomplete-select-multiply-container--classic.extended-autocomplete-select-multiply-container--open .extended-autocomplete-select-multiply-selection--single .extended-autocomplete-select-multiply-selection__arrow {
    background: transparent;
    border: none;
}

.extended-autocomplete-select-multiply-container--classic.extended-autocomplete-select-multiply-container--open .extended-autocomplete-select-multiply-selection--single .extended-autocomplete-select-multiply-selection__arrow b {
    border-color: transparent transparent #888 transparent;
    border-width: 0 4px 5px 4px;
}

.extended-autocomplete-select-multiply-container--classic.extended-autocomplete-select-multiply-container--open.extended-autocomplete-select-multiply-container--above .extended-autocomplete-select-multiply-selection--single {
    border-top: none;
    border-top-left-radius: 0;
    border-top-right-radius: 0;
    background-image: -webkit-linear-gradient(top, white 0%, #eeeeee 50%);
    background-image: -o-linear-gradient(top, white 0%, #eeeeee 50%);
    background-image: linear-gradient(to bottom, white 0%, #eeeeee 50%);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#FFFFFFFF', endColorstr='#FFEEEEEE', GradientType=0);
}

.extended-autocomplete-select-multiply-container--classic.extended-autocomplete-select-multiply-container--open.extended-autocomplete-select-multiply-container--below .extended-autocomplete-select-multiply-selection--single {
    border-bottom: none;
    border-bottom-left-radius: 0;
    border-bottom-right-radius: 0;
    background-image: -webkit-linear-gradient(top, #eeeeee 50%, white 100%);
    background-image: -o-linear-gradient(top, #eeeeee 50%, white 100%);
    background-image: linear-gradient(to bottom, #eeeeee 50%, white 100%);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#FFEEEEEE', endColorstr='#FFFFFFFF', GradientType=0);
}

.extended-autocomplete-select-multiply-container--classic .extended-autocomplete-select-multiply-selection--multiple {
    background-color: white;
    border: 1px solid #aaa;
    border-radius: 0px;
    cursor: text;
    outline: 0;
}

.extended-autocomplete-select-multiply-container--classic .extended-autocomplete-select-multiply-selection--multiple:focus {
    border: 1px solid #5897fb;
}

.extended-autocomplete-select-multiply-container--classic .extended-autocomplete-select-multiply-selection--multiple .extended-autocomplete-select-multiply-selection__rendered {
    list-style: none;
    margin: 0;
    padding: 0 5px;
}

.extended-autocomplete-select-multiply-container--classic .extended-autocomplete-select-multiply-selection--multiple .extended-autocomplete-select-multiply-selection__clear {
    display: none;
}

.extended-autocomplete-select-multiply-container--classic .extended-autocomplete-select-multiply-selection--multiple .extended-autocomplete-select-multiply-selection__choice {
    background-color: #e4e4e4;
    border: 1px solid #aaa;
    border-radius: 0px;
    cursor: default;
    float: left;
    margin-right: 5px;
    margin-top: 5px;
    padding: 0 5px;
}

.extended-autocomplete-select-multiply-container--classic .extended-autocomplete-select-multiply-selection--multiple .extended-autocomplete-select-multiply-selection__choice__remove {
    color: #888;
    cursor: pointer;
    display: inline-block;
    font-weight: bold;
    margin-right: 2px;
}

.extended-autocomplete-select-multiply-container--classic .extended-autocomplete-select-multiply-selection--multiple .extended-autocomplete-select-multiply-selection__choice__remove:hover {
    color: #555;
}

.extended-autocomplete-select-multiply-container--classic[dir="rtl"] .extended-autocomplete-select-multiply-selection--multiple .extended-autocomplete-select-multiply-selection__choice {
    float: right;
    margin-left: 5px;
    margin-right: auto;
}

.extended-autocomplete-select-multiply-container--classic[dir="rtl"] .extended-autocomplete-select-multiply-selection--multiple .extended-autocomplete-select-multiply-selection__choice__remove {
    margin-left: 2px;
    margin-right: auto;
}

.extended-autocomplete-select-multiply-container--classic.extended-autocomplete-select-multiply-container--open .extended-autocomplete-select-multiply-selection--multiple {
    border: 1px solid #5897fb;
}

.extended-autocomplete-select-multiply-container--classic.extended-autocomplete-select-multiply-container--open.extended-autocomplete-select-multiply-container--above .extended-autocomplete-select-multiply-selection--multiple {
    border-top: none;
    border-top-left-radius: 0;
    border-top-right-radius: 0;
}

.extended-autocomplete-select-multiply-container--classic.extended-autocomplete-select-multiply-container--open.extended-autocomplete-select-multiply-container--below .extended-autocomplete-select-multiply-selection--multiple {
    border-bottom: none;
    border-bottom-left-radius: 0;
    border-bottom-right-radius: 0;
}

.extended-autocomplete-select-multiply-container--classic .extended-autocomplete-select-multiply-search--dropdown .extended-autocomplete-select-multiply-search__field {
    border: 1px solid #aaa;
    outline: 0;
}

.extended-autocomplete-select-multiply-container--classic .extended-autocomplete-select-multiply-search--inline .extended-autocomplete-select-multiply-search__field {
    outline: 0;
    box-shadow: none;
}

.extended-autocomplete-select-multiply-container--classic .extended-autocomplete-select-multiply-dropdown {
    background-color: white;
    border: 1px solid transparent;
}

.extended-autocomplete-select-multiply-container--classic .extended-autocomplete-select-multiply-dropdown--above {
    border-bottom: none;
}

.extended-autocomplete-select-multiply-container--classic .extended-autocomplete-select-multiply-dropdown--below {
    border-top: none;
}

.extended-autocomplete-select-multiply-container--classic .extended-autocomplete-select-multiply-results>.extended-autocomplete-select-multiply-results__options {
    max-height: 200px;
    overflow-y: auto;
}

.extended-autocomplete-select-multiply-container--classic .extended-autocomplete-select-multiply-results__option[role=group] {
    padding: 0;
}

.extended-autocomplete-select-multiply-container--classic .extended-autocomplete-select-multiply-results__option[aria-disabled=true] {
    color: grey;
}

.extended-autocomplete-select-multiply-container--classic .extended-autocomplete-select-multiply-results__option--highlighted[aria-selected] {
    background-color: #3875d7;
    color: white;
}

.extended-autocomplete-select-multiply-container--classic .extended-autocomplete-select-multiply-results__group {
    cursor: default;
    display: block;
    padding: 6px;
}

.extended-autocomplete-select-multiply-container--classic.extended-autocomplete-select-multiply-container--open .extended-autocomplete-select-multiply-dropdown {
    border-color: #5897fb;
}

/** TODO: We need to add different styles like classic and so on... **/
.extended-autocomplete-select-multiply-selection__span {
    padding: 2px;
    border-left: solid 1px #888;
    margin: 2px 3px 0px 3px;
}

/** TODO: We need to add different styles like classic and so on... **/
.extended-autocomplete-select-multiply-selection__span_input {
    padding: 2px;
    border-left: solid 1px #888;
    margin: 2px 8px 0px 3px;
}